# libpythonpro
Módulo para exemplificar construção de projetos Python no curso PyTools

Link para o curso [Python Pro] (https://pythonpro.com.br/)

Suportada versão 3 de python


[![Updates](https://pyup.io/repos/github/breeeno/libpythonpro/shield.svg)](https://pyup.io/repos/github/breeeno/libpythonpro/)
[![Python 3](https://pyup.io/repos/github/breeeno/libpythonpro/python-3-shield.svg)](https://pyup.io/repos/github/breeeno/libpythonpro/)

Para instalar:

``console
python 3 -m venv .venv
source .venv/bin/activate
pip install -r requirements.txt``

Para conferir qualidade do código:

``console
flake8
``
